from typing import List, Optional

from sqlalchemy.orm import Session

from app.crud.base import CRUDBase
from app.models.project import Project
from app.schemas.project import ProjectCreate, ProjectUpdate


class CRUDProject(CRUDBase[Project, ProjectCreate, ProjectUpdate]):
    def get_by_slug(self, db: Session, *, slug: str) -> Optional[Project]:
        return db.query(Project).filter(Project.slug == slug).first()

    def get_active(self, db: Session, *, skip: int = 0, limit: int = 100) -> List[Project]:
        return (
            db.query(Project)
            .filter(Project.is_active)
            .offset(skip)
            .limit(limit)
            .all()
        )
    
    def get_featured(self, db: Session, *, skip: int = 0, limit: int = 100) -> List[Project]:
        return (
            db.query(Project)
            .filter(Project.is_active, Project.is_featured)
            .offset(skip)
            .limit(limit)
            .all()
        )


project = CRUDProject(Project)