from typing import List

from sqlalchemy.orm import Session

from app.crud.base import CRUDBase
from app.models.team_member import TeamMember
from app.schemas.team_member import TeamMemberCreate, TeamMemberUpdate


class CRUDTeamMember(CRUDBase[TeamMember, TeamMemberCreate, TeamMemberUpdate]):
    def get_active(self, db: Session, *, skip: int = 0, limit: int = 100) -> List[TeamMember]:
        return (
            db.query(TeamMember)
            .filter(TeamMember.is_active)
            .order_by(TeamMember.order.asc())
            .offset(skip)
            .limit(limit)
            .all()
        )


team_member = CRUDTeamMember(TeamMember)