from datetime import datetime
from typing import Optional

from pydantic import BaseModel, EmailStr, Field


# Shared properties
class ContactBase(BaseModel):
    name: Optional[str] = None
    email: Optional[EmailStr] = None
    phone: Optional[str] = None
    subject: Optional[str] = None
    message: Optional[str] = None
    is_read: Optional[bool] = False


# Properties to receive via API on creation
class ContactCreate(ContactBase):
    name: str = Field(..., min_length=1, max_length=100)
    email: EmailStr
    message: str


# Properties to receive via API on update
class ContactUpdate(ContactBase):
    pass


class ContactInDBBase(ContactBase):
    id: int
    name: str
    email: EmailStr
    message: str
    created_at: datetime
    updated_at: Optional[datetime] = None

    class Config:
        from_attributes = True


# Additional properties to return via API
class Contact(ContactInDBBase):
    pass